********************************************************************************
********************************************************************************
* 						THE COVID-19 CONSUMPTION GAME-CHANGER:
*					EVIDENCE FROM A LARGE-SCALE MULTI-COUNTRY SURVEY		  
* 								    
* 					(Italy, Spain, France, Germany, Netherlands)
*
* 	AUTHORS: Alexander Hodbod; Cars Hommes; Stefanie J. Huber; Isabelle Salle
********************************************************************************


********************************************************************************
* Note: This do-file cleans the raw data / creates variables used in the analysis
********************************************************************************

clear all
set more off

use "data/COVID-19_conso_data.dta", clear


********************************************************************************
********************************************************************************
* MERGE COUNTRY CODES (ISO 3166-1 alpha-3 codes)
********************************************************************************
********************************************************************************

	codebook country
	
	gen countrycode="."
	replace countrycode="DEU" if country==2
	replace countrycode="ITA" if country==3
	replace countrycode="ESP" if country==6
	replace countrycode="FRA" if country==1
	replace countrycode="NLD" if country==5

  * total number of observations from country X	

	tab country
	table country

********************************************************************************
********************************************************************************
* MERGE COUNTRY's number of deaths/1M population 
* for July 10th, 2020. Source: https://www.worldometers. info/coronavirus/.
********************************************************************************
********************************************************************************

gen deaths=.

	replace deaths=109 if countrycode=="DEU" 
	replace deaths=580 if countrycode=="ITA" 
	replace deaths=607 if countrycode=="ESP" 
	replace deaths=459 if countrycode=="FRA" 
	replace deaths=358 if countrycode=="NLD" 

********************************************************************************
********************************************************************************
*					INDIVIDUAL CHARACTERISTICS
********************************************************************************
********************************************************************************


********************************************************************************
* AGE (Age gives each person's age in three chategories)
********************************************************************************

 * 			 tabulation:  Freq.   Numeric  Label
 *                        1,788         1  18-34
 *                        2,603         2  35-54
 *                        3,110         3  55+

codebook age

rename age age_groups

********************************************************************************
* YEAR (year gives each person's birth year; q4)
* calculate Age (approx.); i.e., age gives each person's age by the end of 2020.

gen age=.
replace age=(2020-q4)

gen agesquare= age*age
label var agesquare "Age, squared"

********************************************************************************
* GENDER 
********************************************************************************
 *			tabulation:  Freq.   Numeric  Label
 *                        3,669         1  Male
 *                        3,826         2  Female
 *                            5         3  Other
 *                            1         4  I prefer not to say

codebook q5

* create new variables (Male, Female), drop "other" and "I prefer not to say"

gen male=.
replace male=0 if q5==2
replace male=1 if q5==1

	label def yes_no 1 "Male" 0 "Female"
	label val male yes_no
	
tab male

gen female=.
replace female=1 if q5==2
replace female=0 if q5==1

	label def yes_no1 1 "Female" 0 "Male"
	label val female yes_no1

tab female



********************************************************************************
* EDUCATION (two chategorical variables)
********************************************************************************
* education_r1

*		tabulation:  Freq.   Numeric  Label
*                            21         0  Not finished primary
*                           359         1  Primary
*                         1,928         2  Lower secondary
*                         2,798         3  Upper secondary
*                           317         4  Post-secondary non tertiary
*                           383         5  Short-cycle tertiary
*                           655         6  Bachelor or equivalent
*                           982         7  Master or equivalent
*                            58         8  Doctoral or equivalent

							
* education_r2							
							
*            tabulation:  Freq.   Numeric  Label
*                         2,292         1  Low
*                         3,131         2  Middle
*                         2,078         3  High


gen loweduc=.
replace loweduc=1 if education_r2==1
replace loweduc=0 if education_r2==2
replace loweduc=0 if education_r2==3

gen mideduc=.
replace mideduc=1 if education_r2==2
replace mideduc=0 if education_r2==1
replace mideduc=0 if education_r2==3

gen higheduc=.
replace higheduc=1 if education_r2==3
replace higheduc=0 if education_r2==1
replace higheduc=0 if education_r2==2
********************************************************************************
* HOUSEHOLD SIZE
********************************************************************************
*q13: How many people currently live in your household?

	tabulate q13
 
	rename q13 householdsize

	tabulate householdsize
	
********************************************************************************
* NUMBER OF CHILDREN (nchild)
********************************************************************************
* Def. NCHILD counts the number of own children (of age < 14) 
* residing with each individual. NCHILD includes step-children and adopted 
* children as well as biological children. 
* Persons with no children present are coded 0.

rename q13b nchild

tabulate nchild

********************************************************************************
* NUMBER OF ADULTS (nadult)
********************************************************************************
* gives the number of additional adults that live in household.

rename numothadult nadult



********************************************************************************
* INCOME (q16)
********************************************************************************

* Q16: Can you tell us which value describes your household's yearly total 
* income, after tax and compulsory deductions, from all sources? 
* If you don't know the exact figure, please give an estimate. 
* categorical variable (11 categories), numeric 1-11.

gen income10=.
replace income10=1 if q16==1
replace income10=2 if q16==2
replace income10=3 if q16==3
replace income10=4 if q16==4
replace income10=5 if q16==5
replace income10=6 if q16==6
replace income10=7 if q16==7
replace income10=8 if q16==8
replace income10=9 if q16==9
replace income10=10 if q16==10

********************************************************************************
* income (three categories)
********************************************************************************

*            tabulation:  Freq.   Numeric  Label
*                         2,440         1  Low
*                         2,639         2  Middle
*                         1,609         3  High
*                           813         4  Refuse

gen income3_answered =.
replace income3_answered=1 if income==1
replace income3_answered=2 if income==2
replace income3_answered=3 if income==3

********************************************************************************
* EMPLOYMENT STATUS	
********************************************************************************

* Q10a: Which of these descriptions best applies to what you have been doing for 
* the last month before the covid-19 outbreak?

* Answers (11 categories):
*            tabulation:  Freq.   Numeric  Label
*                         3,570         1  Paid work
*                           360         2  Education or training
*                           433         3  Unemployment, actively looking
*                                          for a job
*                           124         4  Unemployment, wanting a job but
*                                          not actively looking for a job
*                           229         5  Permanently sick or disabled
*                         2,010         6  Retired
*                            18         7  Community or military service
*                                          (unpaid)
*                           503         8  Housework, looking after
*                                          children and/or other persons
*                           200         9  Other
*                            43        10  I prefer not to answer
*                            11        11  I don't know


		gen empstat3=.
		replace empstat3=1 if q10a==1
		replace empstat3=2 if q10a==3 | q10a==4
		replace empstat3=3 if q10a==2 | q10a==5| q10a==6| q10a==7 |q10a==8 
		tab empstat3
		
		label var empstat3 "Employment Status - 3 categories"
		cap label def empst 1 "has a paid job" 2 "unemployed" 3 "not in labour force"
		label val empstat3 empst
		
		gen empstat4=.
		replace empstat4=1 if q10a==1
		replace empstat4=2 if q10a==3 | q10a==4
		replace empstat4=3 if q10a==2 | q10a==5| q10a==6| q10a==7 
		replace empstat4=4 if q10a==8
		tab empstat4
		
		label var empstat4 "Employment Status - 4 categories"
		cap label def empst4 1 "has a paid job" 2 "unemployed" 3 "not in labour force" 4 "housewife/househusband"
		label val empstat4 empst4
		
		gen job=0 
		replace job=1 if empstat3==1
		replace job=. if empstat3==.

		gen unemployed=0
		replace unemployed=1 if empstat3==2
		replace unemployed=. if empstat3==.

		gen notinLF=0
		replace notinLF=1 if empstat3==3
		replace notinLF=. if empstat3==.

*******************************************************************************
* UNEMPLOYEMNT SPELL OVER LAST 5 YEARS
*******************************************************************************
	
*Q23: Have you been unemployed and seeking work for more than 3 months in the last 5 years?

*            tabulation:  Freq.   Numeric  Label
*                         1,761         1  Yes
*                         5,602         2  No
*                           138         3  I prefer not to answer

gen pastunempl=.
replace pastunempl=1 if q23==1
replace pastunempl=0 if q23==2

		label var pastunempl "Unemployment Spell in past 5 years - Dummy"
		cap label def past 1 "YES" 0 "NO" 
		label val pastunempl past

*******************************************************************************
* PROFESSION	(conditional on employment)
********************************************************************************

* Q10b: If you are currently employed, which of the following descriptions 
* best describes your job?

* 10 categories

 codebook q10b, tab(100)
 
*  tabulation:  Freq.   Numeric  Label
*                           247         1  Managers
*                           527         2  Professionals
*                           494         3  Technicians and associate
*                                          professionals
*                           908         4  Clerical support workers
*                           619         5  Service and sales workers
*                            38         6  Skilled agricultural, forestry
*                                          and fishery workers
*                           308         7  Craft and related trades workers
*                           134         8  Plant and machine operators, and
*                                          assemblers
*                           243         9  Elementary occupations
*                            52        10  Armed forces
*                         3,931         .  




********************************************************************************
* SAVINGS (q47new)
********************************************************************************

* Q47new: Does your household have savings (excluding the value of your home) 
* worth at least one month of the total net income of  your household? 

* Numeric: 1-4

* tabulation:  Freq.   Numeric  Label
*                         4,304         1  Yes
*                         2,234         2  No
*                           438         3  I don’t know
*                           525         4  I prefer not to answer


* create yes/no saving variable, drop I don’t know & I prefer not to answer:

gen savings=.
replace savings=1 if q47new==1
replace savings=0 if q47new==2

		label var savings "Savings of at least one month of total household net income"
		cap label def savi 1 "YES" 0 "NO" 
		label val savings savi
				 
								 
********************************************************************************
********************************************************************************
* 					CONTROLS FOR LOCATION OF RESIDENCE 
*					    		REGIONS
********************************************************************************
********************************************************************************

* GERMANY - BUNDESLÄNDER (16) 
********************************************************************************
codebook region_de_nuts1,  tab(100)
	
* SPAIN
********************************************************************************
* REGIONS (7) 
codebook region_es_nuts1,  tab(100)
* REGIONS (17) 
codebook region_es_nuts2,  tab(100)

* FRANCE
********************************************************************************
* REGIONS (8) 
codebook region_fr_nuts1,  tab(100)
* REGIONS (22) 
codebook region_fr_nuts2,  tab(100)

* ITALY
********************************************************************************
* REGIONS (5) 
codebook region_it_nuts1,  tab(100)
* REGIONS (20) 
codebook region_it_nuts2,  tab(100)

* NETHERLANDS
********************************************************************************
* REGIONS (4) 
codebook region_nl_nuts1,  tab(100)
* REGIONS (12) 
codebook region_nl_nuts2,  tab(100)

********************************************************************************
********************************************************************************
* 							BEHAVIORAL DATA 
*					   			WORRY
********************************************************************************
********************************************************************************

********************************************************************************
* FEELING ABOUT PERSONAL HOUSEHOLD INCOME
********************************************************************************

* Q19: Which of these descriptions comes closest to how you feel about your 
* household's income nowadays?

* coded numeric, 1-6.

*            tabulation:  Freq.   Numeric  Label
*                           705         1  Very difficult on present income
*                                          and insufficient to cover all
*                                          the expenses
*                         1,475         2  Difficult on present income
*                         2,663         3  Coping on present income
*                         1,144         4  Living comfortably on present
*                                          income, but unable to save
*                         1,298         5  Living comfortably on present
*                                          income and able to save
*                           216         6  I prefer not to answer

gen incomefeel=.
replace incomefeel=1 if q19==1
replace incomefeel=2 if q19==2
replace incomefeel=3 if q19==3
replace incomefeel=4 if q19==4
replace incomefeel=5 if q19==5

********************************************************************************
* UNEMPLOYMENT WORRY
********************************************************************************
* Q22: How worried are you about losing your job in the near future?

*             tabulation:  Freq.   Numeric  Label
*                           806         1  Very worried
*                         1,635         2  Somewhat worried
*                         2,056         3  Not worried
*                           381         4  I am already unemployed
*                         2,467         5  I am not working and I am not
*                                          looking for a job (e.g. student,
*                                          retiree, housewife, etc.)
*                           156         6  I prefer not to answer

* new variable, drop all out of labor (worry conditional of being employed)
gen worryjobloss=.
replace worryjobloss=3 if q22==1
replace worryjobloss=2 if q22==2
replace worryjobloss=1 if q22==3


********************************************************************************
* EXPECTATION ABOUT COVID-19 EFFECT ON OWN FINANCIAL SITUATION
********************************************************************************
* Q50new: How concerned are you about the effects that the coronavirus might 
* have for the financial situation your household? 

* Answer option: 0-10. 0 (Not at all concerned) to 10 (Extremely concerned) 
* 204 missing (prefer not to say)

rename q50new worryfinance


********************************************************************************
* EXPECTATION ABOUT LENGTH OF COVID-19 CRISIS
********************************************************************************

* Q52new: in your opinion, when will COVID-19 be totally under control such that it 
* is safe to release all COVID-19 containment measures in your country? 

* coded 1-5, the higher the number the later the expected end date.

*In your opinion, when |
*     will COVID-19 be |
* totally under control |
*  such that it is saf |      Freq.     Percent        Cum.
*----------------------+-----------------------------------
*  July-September-2020 |        371        4.95        4.95
*October-December 2020 |        847       11.29       16.24
*    January-June 2021 |      2,316       30.88       47.11
*   July-December 2021 |      2,026       27.01       74.12
*                Later |      1,941       25.88      100.00
*----------------------+-----------------------------------
*                Total |      7,501      100.00

				
rename q52new crisisend				

********************************************************************************
* EXPECTATION ABOUT UNEMPLOYMENT
********************************************************************************

*q48new:
*Please indicate what you think the unemployment rate was or will be in your 
*country at different points in time:

*before the crisis: _____  % [0 to 100]
*Now:  _____  % [0 to 100]
*1 year from now: _____  % [0 to 100] 
*2 to 3 years from now: _____  % [0 to 100]

rename q48new_1 unempl_before
rename q48new_2 unempl_now
rename q48new_3 unempl_1year
rename q48new_4 unempl_2years

generate diffexp_unempl =.
replace diffexp_unempl=unempl_now-unempl_before

generate diffexp_unempl2 =.
replace diffexp_unempl2=unempl_1year-unempl_before
********************************************************************************
* PERSONAL EXPERIENCE/EXPOSURE TO COVID-19 INFECTION
********************************************************************************

* Q49new: Did you or a person close to you suffer from severe Covid-19 infection?

* tabulation:  Freq.   Numeric  Label
*                           664         1  Yes
*                         6,745         2  No
*                            92         3  I prefer not to say

* create dummy:
gen infection=.
replace infection=1 if q49new==1
replace infection=0 if q49new==2


		label var infection "Severe COVID-19 infection"
		cap label def infect 1 "YES" 0 "NO" 
		label val infection infect
		
		
********************************************************************************
* TRUST --- GOVERMENT
********************************************************************************

* TRUST Q39_1: Please tell us how much you personally trust or distrust the
* {#Country2} government?

*             tabulation:  Freq.   Numeric  Label
*                           757         1  Very much trust
*                         2,258         2  Somewhat trust
*                         1,448         3  Neither trust nor distrust
*                         1,304         4  Somewhat distrust
*                         1,538         5  Very much distrust
*                           124         6  I don’t know
*                            72         7  I prefer not to answer

gen trust=.
replace trust=1 if q39_1==1
replace trust=2 if q39_1==2
replace trust=3 if q39_1==3
replace trust=4 if q39_1==4
replace trust=5 if q39_1==5

		label var trust "Trust in goverment"
		cap label def trustg 1 "Very much trust" 2 "Somewhat trust" 3 "Neither trust nor distrust" 4 "Somewhat distrust" 5 "Very much distrust"
		label val trust trustg

********************************************************************************
* SATISFACTION WITH GOVERMENT
********************************************************************************

* SATISFACTION Q40_1: How satisfied are you with the way the (#country_name) 
* government led by (#country_leader_name) is doing its job?

* 1=Very much satisfied /Somewhat satisfied / Neither satisfied nor dissatisfied/ 
*Somewhat dissatisfied / Very much dissatisfied / 6=I prefer not to answer

gen satisfaction=.
replace satisfaction=1 if q40_1==1
replace satisfaction=2 if q40_1==2
replace satisfaction=3 if q40_1==3
replace satisfaction=4 if q40_1==4
replace satisfaction=5 if q40_1==5

		label var satisfaction "Satisfaction with goverment"
		cap label def statis 1 "Very much satisfied" 2 "Somewhat satisfied" 3 "Neither satisfied nor dissatisfied" 4 "Somewhat dissatisfied" 5 "Very much dissatisfied"
		label val satisfaction satis


	
********************************************************************************
********************************************************************************
* 							CONSUMPTION DATA 
*					   		  
********************************************************************************
********************************************************************************
 
********************************************************************************
********************************************************************************
* BEHAVIOR DURING DANCE PHASE Q45
********************************************************************************
********************************************************************************

* Compared to before the Covid-19 outbreak, how would you behave? 
* 1 = more often than before 
* 2= same as before 
* 3 = less often than before 
* 4 = not at all 
* 5= I never did this before

* Randomize order of activities:
* q45new_1: I would use public transports 
* q45new_2: I would travel abroad for private reasons
* q45new_3: I would use services such as hairdressers or beauty salons 
* q45new_4: I would visit restaurants, bars, and cafés 
* q45new_5: I would shop in malls or other stores


rename q45new_1 transport
rename q45new_2 travel
rename q45new_3 services
rename q45new_4 restaurants
rename q45new_5 shops

gen lesstransport=.
replace lesstransport=1 if transport==3 | transport==4
replace lesstransport=0 if transport==1 | transport==2
tab lesstransport

		label var lesstransport "I would use public transports less often"
		cap label def trans 1 "YES" 0 "NO" 
		label val lesstransport trans

gen transport3=.
replace transport3=1 if transport==3 | transport==4
replace transport3=2 if transport==2
replace transport3=3 if transport==1
tab transport3
		
		label var transport3 "I would use public transports"
		cap label def trans3 1 "Less often" 2 "same as before" 3 "more"
		label val transport3 trans3
		
	
gen lesstravel=.
replace lesstravel=1 if travel==3 | travel==4
replace lesstravel=0 if travel==1 | travel==2
tab lesstravel

		label var lesstransport "I would travel less often"
		cap label def trav 1 "YES" 0 "NO" 
		label val lesstravel trav

gen travel3=.
replace travel3=1 if travel==3 | travel==4
replace travel3=2 if travel==2
replace travel3=3 if travel==1
tab travel3
		
		label var travel3 "I would travel"
		cap label def trav3 1 "Less often" 2 "same as before" 3 "more"
		label val travel3 trav3

gen lessservices=.
replace lessservices=1 if services==3 | services==4
replace lessservices=0 if services==1 | services==2
tab lessservices

		label var lessservices "I would use services less often"
		cap label def serv 1 "YES" 0 "NO" 
		label val lessservices serv

gen services3=.
replace services3=1 if services==3 | services==4
replace services3=2 if services==2
replace services3=3 if services==1
tab services3
		
		label var services3 "I would use services"
		cap label def serv3 1 "Less often" 2 "same as before" 3 "more"
		label val services3 serv3
		
gen lessrestaurants=.
replace lessrestaurants=1 if restaurants==3 | restaurants==4
replace lessrestaurants=0 if restaurants==1 | restaurants==2
tab lessrestaurants

		label var lessrestaurants "I would visit restaurants less often"
		cap label def rest 1 "YES" 0 "NO" 
		label val lessrestaurants rest

gen restaurants3=.
replace restaurants3=1 if restaurants==3 | restaurants==4
replace restaurants3=2 if restaurants==2
replace restaurants3=3 if restaurants==1
tab restaurants3
		
		label var restaurants3 "I would visit restaurants"
		cap label def rest3 1 "Less often" 2 "same as before" 3 "more"
		label val restaurants3 rest3		
		
		
gen lessshops=.
replace lessshops=1 if shops==3 | shops==4
replace lessshops=0 if shops==1 | shops==2
tab lessshops

		label var lessshops "I would shop in malls/stors less often"
		cap label def shop 1 "YES" 0 "NO" 
		label val lessshops shop

gen shops3=.
replace shops3=1 if shops==3 | shops==4
replace shops3=2 if shops==2
replace shops3=3 if shops==1
tab shops3
		
		label var shops3 "I would shop in malls/stors"
		cap label def shop3 1 "Less often" 2 "same as before" 3 "more"
		label val shops3 shop3
		
		
********************************************************************************
********************************************************************************
* RESEONS FOR CHANGE IN BEHAVIOR Q46
********************************************************************************
********************************************************************************

* What is your main reason for doing now less of the following activities?

*        Numeric  Label
*               1  I plan to buy more online
*               2  I realized I don’t miss it
*               3  I want to save more
*			    4  I cannot afford it anymore
*               5  I am worried to get infected with COVID-19
*               6  Other reason

rename q46new_1 whytransport
rename q46new_2 whytravel
rename q46new_3 whyservices
rename q46new_4 whyrestaurants
rename q46new_5 whyshops

* Note: In some cases, some answers make no sense; 
* e.g. I use less public transport, because I buy more online (...)
* very few cases, create new variable and drop these observations:

gen whytransportclean=.
replace whytransportclean=1 if whytransport==2
replace whytransportclean=2 if whytransport==3
replace whytransportclean=3 if whytransport==4
replace whytransportclean=4 if whytransport==5
replace whytransportclean=5 if whytransport==6

		
		label var whytransportclean "Main reason for using now less public transport"
		cap label def whytrans 1 "not missing it" 2 "wanting to save more" 3 "not affordable" 4 "infection risk" 5 "other reason" 
		label val whytransportclean whytrans
		
tab whytransportclean


gen whytravelclean=.
replace whytravelclean=1 if whytravel==2
replace whytravelclean=2 if whytravel==3
replace whytravelclean=3 if whytravel==4
replace whytravelclean=4 if whytravel==5
replace whytravelclean=5 if whytravel==6

		
		label var whytravelclean "Main reason for traveling now less abroad"
		cap label def whytrav 1 "not missing it" 2 "wanting to save more" 3 "not affordable" 4 "infection risk" 5 "other reason" 
		label val whytravelclean whytrav
		
tab whytravelclean


gen whyservicesclean=.
replace whyservicesclean=1 if whyservices==2
replace whyservicesclean=2 if whyservices==3
replace whyservicesclean=3 if whyservices==4
replace whyservicesclean=4 if whyservices==5
replace whyservicesclean=5 if whyservices==6

		
		label var whyservicesclean "Main reason for using now less services such as hairdressers"
		cap label def whyserv 1 "not missing it" 2 "wanting to save more" 3 "not affordable" 4 "infection risk" 5 "other reason" 
		label val whyservicesclean whyserv
		
tab whyservicesclean


gen whyrestaurantsclean=.

replace whyrestaurantsclean=1 if whyrestaurants==1
replace whyrestaurantsclean=2 if whyrestaurants==2
replace whyrestaurantsclean=3 if whyrestaurants==3
replace whyrestaurantsclean=4 if whyrestaurants==4
replace whyrestaurantsclean=5 if whyrestaurants==5
replace whyrestaurantsclean=6 if whyrestaurants==6

		
		label var whyrestaurantsclean "Main reason for going now less to restaurants, bars, and cafés"
		cap label def whyrest 1 "buy more online instead" 2 "not missing it" 3 "wanting to save more" 4 "not affordable" 5 "infection risk" 6 "other reason" 
		label val whyrestaurantsclean whyrest


gen whyshopsclean=.

replace whyshopsclean=1 if whyshops==1
replace whyshopsclean=2 if whyshops==2
replace whyshopsclean=3 if whyshops==3
replace whyshopsclean=4 if whyshops==4
replace whyshopsclean=5 if whyshops==5
replace whyshopsclean=6 if whyshops==6

		
		label var whyshopsclean "Main reason for shopping now less in malls or other stores"
		cap label def whysh 1 "buy more online instead" 2 "not missing it" 3 "wanting to save more" 4 "not affordable" 5 "infection risk" 6 "other reason" 
		label val whyshopsclean whysh

gen whyrestaurantsclean2=.

replace whyrestaurantsclean2=1 if whyrestaurants==2
replace whyrestaurantsclean2=2 if whyrestaurants==3
replace whyrestaurantsclean2=3 if whyrestaurants==4
replace whyrestaurantsclean2=4 if whyrestaurants==5
replace whyrestaurantsclean2=5 if whyrestaurants==6
replace whyrestaurantsclean2=6 if whyrestaurants==1


		
		label var whyrestaurantsclean2 "Main reason for going now less to restaurants, bars, and cafés"
		cap label def whyrest2 1 "not missing it" 2 "wanting to save more" 3 "not affordable" 4 "infection risk" 5 "other reason" 6 "buy more online instead"
		label val whyrestaurantsclean2 whyrest2


gen whyshopsclean2=.

replace whyshopsclean2=1 if whyshops==2
replace whyshopsclean2=2 if whyshops==3
replace whyshopsclean2=3 if whyshops==4
replace whyshopsclean2=4 if whyshops==5
replace whyshopsclean2=5 if whyshops==6
replace whyshopsclean2=6 if whyshops==1

		
		label var whyshopsclean2 "Main reason for shopping now less in malls or other stores"
		cap label def whysh2 1 "not missing it" 2 "wanting to save more" 3 "not affordable" 4 "infection risk" 5 "other reason" 6 "buy more online instead"
		label val whyshopsclean2 whysh2



save "Data/master_readytogo.dta", replace
